@@ -514,6 +514,7 @@ is non-nil, don't quit if the info is already there."
               (funcall mode)
               (when (featurep 'font-lock)
                 (put mode 'mmm-font-lock-mode font-lock-mode)
+                (font-lock-set-defaults)
                 ;; These can't be in the local variables list, because we
                 ;; replace their actual values, but we want to use their
                 ;; original values elsewhere.
@@ -710,10 +711,7 @@ region and mode for the previous position."
   "Re-fontify from START to STOP, or entire buffer, if enabled."
   (when font-lock-mode
     (if (fboundp 'font-lock-flush)
-        (progn
-          (font-lock-flush start stop)
-          ;; FIXME: Do we really need to do this eagerly here?
-          (font-lock-ensure start stop))
+        (font-lock-flush start stop)
       (if (or start stop)
           (font-lock-fontify-region (or start (point-min))
                                     (or stop (point-max)))
@@ -876,7 +874,7 @@ calls each respective submode's `syntax-propertize-function'."
                       (cond
                        (func
                         (funcall func beg end))
-                       (font-lock-syntactic-keywords
+                       ((bound-and-true-p font-lock-syntactic-keywords)
                         (let ((syntax-propertize-function nil))
                           (font-lock-fontify-syntactic-keywords-region beg end))))
                       (run-hook-with-args 'mmm-after-syntax-propertize-functions
