@@ -145,6 +145,7 @@
     (c-extra-toplevel-key nil ,mmm-c-derived-modes)
     (c-inexpr-class-key nil ,mmm-c-derived-modes)
     (c-conditional-key nil ,mmm-c-derived-modes)
+    (nxml-prolog-end region (nxml-mode))
     semantic-bovinate-toplevel-override
     semantic-toplevel-bovine-table
     ;; Indentation style control variables.
@@ -183,6 +184,7 @@
 	 c-comment-prefix-regexp
 	 c-comment-start-regexp
 	 c-cpp-defined-fns
+         c-cpp-expr-functions-key
 	 c-current-comment-prefix
 	 c-decl-block-key
          c-decl-hangon-key
@@ -192,9 +194,11 @@
          c-decl-start-kwds
          c-decl-start-re
 	 c-doc-comment-start-regexp
+         ;; c-enum-clause-introduction-re
 	 c-expr-kwds
 	 c-file-offsets
 	 c-file-style
+         c-found-types
          c-not-primitive-type-keywords-regexp
 	 c-hanging-braces-alist
 	 c-hanging-colons-alist
@@ -222,6 +226,9 @@
 	 c-lambda-kwds
          c-literal-start-regexp
 	 c-macro-with-semi-re
+         c-make-top-level-key
+         ;; c-make-top-level-kwds
+         c-noise-macro-with-parens-name-re
          c-nonlabel-token-key
          c-nonlabel-token-2-key
          c-nonsymbol-chars
@@ -255,6 +262,7 @@
 	 c-other-decl-block-kwds
 	 c-other-decl-kwds
 	 c-overloadable-operators-regexp
+         c-pack-key
          c-paragraph-separate
          c-paragraph-start
          c-paren-stmt-key
@@ -288,6 +296,7 @@
          c-prefix-spec-kwds-re
          c-typedef-key
 	 c-typedef-decl-key
+         c-type-decl-suffix-ws-ids-key
          comment-end
          comment-start
 	 comment-start-skip))
@@ -295,6 +304,10 @@
        (lambda (var) (list var nil '(js-mode)))
        '(js--quick-match-re
          js--quick-match-re-func))
+    ,@(mapcar
+       (lambda (var) (list var nil '(typescript-mode)))
+       '(typescript--quick-match-re
+         typescript--quick-match-re-func))
     ;; Skeleton insertion
     skeleton-transformation
     ;; Abbrev mode
@@ -871,7 +884,7 @@ regions, and sometimes for inserting new ones while editing.
 
 Each element of this alist looks like \(CLASS . ARGS) where CLASS is a
 symbol naming the submode class and ARGS is a list of keyword
-arguments, called a \"class specifier\". There are a large number of
+arguments, called a \"class specifier\".  There are a large number of
 accepted keyword arguments in the class specifier.
 
 The argument CLASSES, if supplied, must be a list of other submode
@@ -883,8 +896,8 @@ classes can do nothing but group other classes.
 
 The argument HANDLER, if supplied, also overrides any other processing.
 It must be a function, and all the arguments are passed to it as
-keywords, and it must do everything. See `mmm-ify' for what sorts of
-things it must do. This back-door interface should be cleaned up.
+keywords, and it must do everything.  See `mmm-ify' for what sorts of
+things it must do.  This back-door interface should be cleaned up.
 
 The optional argument FACE gives the display face of the submode
 regions under high decoration (see `mmm-submode-decoration-level').
@@ -905,13 +918,13 @@ a match is found for FRONT, which is passed one argument, the form of
 the front delimiter \(found from FRONT-FORM, below), and return a
 symbol such as SUBMODE would be set to.  If MATCH-SUBMODE detects an
 invalid match--for example a specified mode which is not `fboundp'--it
-should \(signal 'mmm-no-matching-submode nil).
+should \(signal \\='mmm-no-matching-submode nil).
 
 FRONT and BACK are the means to find the submode regions, and can be
 either buffer positions \(number-or-markers), regular expressions, or
-functions. If they are absolute buffer positions, only one submode
-region is created, from FRONT to BACK. This is generally not used in
-named classes. \(Unnamed classes are created by interactive commands
+functions.  If they are absolute buffer positions, only one submode
+region is created, from FRONT to BACK.  This is generally not used in
+named classes.  \(Unnamed classes are created by interactive commands
 in `mmm-interactive-history').
 
 If FRONT is a regexp, then that regexp is searched for, and the end of
@@ -954,7 +967,7 @@ delimiter.  If nil, it means not to make a region for the respective
 delimiter at all.
 
 DELIMITER-MODE, if supplied, specifies what submode to use for the
-delimiter regions, if any.  If `nil', the primary mode is used.  If
+delimiter regions, if any.  If nil, the primary mode is used.  If
 not supplied, `mmm-delimiter-mode' is used.
 
 FRONT-FACE and BACK-FACE specify faces to use for displaying the
@@ -974,7 +987,7 @@ delimiter.  See `mmm-match-front', `mmm-match-back', and
 `mmm-end-current-region'.
 
 CASE-FOLD-SEARCH, if specified, controls whether the search is
-case-insensitive. See `case-fold-search'. It defaults to `t'.
+case-insensitive.  See `case-fold-search'.  It defaults to t.
 
 CREATION-HOOK, if specified, should be a function which is run
 whenever a submode region is created, with point at the beginning of
@@ -983,16 +996,16 @@ the new region.  One use for it is to set region-saved local variables
 
 INSERT specifies the keypress insertion spec for such submode regions.
 INSERT's value should be list of elements of the form \(KEY NAME .
-SPEC). Each KEY should be either a character, a function key symbol,
+SPEC).  Each KEY should be either a character, a function key symbol,
 or a dotted list \(MOD . KEY) where MOD is a symbol for a modifier
-key. The use of any other modifier than meta is discouraged, as
+key.  The use of any other modifier than meta is discouraged, as
 `mmm-insert-modifiers' is sometimes set to \(control), and other
-modifiers are not very portable. Each NAME should be a symbol
-representing the insertion for that key. Each SPEC can be either a
+modifiers are not very portable.  Each NAME should be a symbol
+representing the insertion for that key.  Each SPEC can be either a
 skeleton, suitable for passing to `skeleton-insert' to create a
 submode region, or a dotted pair \(OTHER-KEY . ARG) meaning to use the
 skeleton defined for OTHER-KEY but pass it the argument ARG as the
-`str' variable, possible replacing a prompt string. Skeletons for
+`str' variable, possible replacing a prompt string.  Skeletons for
 insertion should have the symbol `_' where point \(or wrapped text)
 should go, and the symbol `@' in four different places: at the
 beginning of the front delimiter, the beginning of the submode region,
@@ -1049,7 +1062,7 @@ The CLASSES are all made private, i.e. non-user-visible."
 ;;}}}
 ;;{{{ Version Number
 
-(defconst mmm-version "0.5.8"
+(defconst mmm-version "0.5.10"
   "Current version of MMM Mode.")
 
 (defun mmm-version ()
