@@ -1,4 +1,4 @@
-;; Copyright (C) 2013  Free Software Foundation, Inc.
+;; Copyright (C) 2013, 2020, 2022  Free Software Foundation, Inc.
 
 ;; This file is part of GNU Emacs.
 
@@ -22,6 +22,7 @@
 (require 'ert)
 (require 'ert-x)
 (require 'mmm-erb)
+(require 'mmm-test-util)
 
 (defvar mmm-erb-text
   "<%= foo do %>
@@ -42,6 +43,7 @@
       (setq body (nthcdr 2 body)))
     `(ert-deftest ,(intern (format "mmm-erb-%s" name)) ()
        :expected-result ,(or expected-result :passed)
+       (mmm-with-global-font-lock
        (ert-with-test-buffer nil
          (let ((buffer-file-name "foo.html.erb")
                (mmm-global-mode 'maybe)
@@ -51,7 +53,7 @@
            (html-erb-mode)
            (mmm-mode-on-maybe)
            (should mmm-mode)
-           ,@body)))))
+           ,@body))))))
 
 (put 'mmm-erb-deftest 'lisp-indent-function 'defun)
 
@@ -66,38 +68,37 @@
   (should (mmm-update-current-submode))
   (should (string= " end " (mmm-erb-current-overlay-string))))
 
-(defun mmm-erb-assert-string-syntax ()
+(defun mmm-erb-assert-string-faces ()
   (goto-char (point-min))
+  (font-lock-ensure (point-min) (point-max))
   (search-forward "\"")
-  (should (nth 3 (syntax-ppss)))
-  (search-forward "\"")
-  (should (not (nth 3 (syntax-ppss)))))
+  (should (eq (get-text-property (point) 'face)
+              'font-lock-string-face)))
 
-(defun mmm-erb-assert-non-string-syntax ()
+(defun mmm-erb-assert-non-string-faces ()
   (goto-char (point-min))
+  (font-lock-ensure (point-min) (point-max))
   (search-forward "\"")
-  (should (not (nth 3 (syntax-ppss))))
-  (search-forward "\"")
-  (should (not (nth 3 (syntax-ppss)))))
+  (should (not (eq (get-text-property (point) 'face)
+                   'font-lock-string-face))))
 
 (mmm-erb-deftest attribute-values-are-strings
   (insert mmm-erb-text)
   (mmm-apply-all)
-  (mmm-erb-assert-string-syntax))
+  (mmm-erb-assert-string-faces))
 
 (mmm-erb-deftest quotes-outside-tags-dont-make-strings
-  :expected-result (if mmm-erb-edge-emacs :passed :failed)
   (insert "<% foo do %><p>\"foo bar\"</p><% end %>")
   (mmm-apply-all)
-  (mmm-erb-assert-non-string-syntax))
+  (mmm-erb-assert-non-string-faces))
 
 (mmm-erb-deftest gt-inside-subregion-doesnt-change-nesting
   (insert "<% if 2 > 1 %><div class=\"foo\"/><% end %>")
   (mmm-apply-all)
-  (mmm-erb-assert-string-syntax))
+  (mmm-erb-assert-string-faces))
 
 (mmm-erb-deftest lt-inside-subregion-doesnt-change-nesting
-  :expected-result (if mmm-erb-edge-emacs :passed :failed)
   (insert "<% if 2 < 1 %><p>\"foo bar\"</p><% end %>")
+  ;; FIXME: Perhaps check sgml-lexical-context as well?
   (mmm-apply-all)
-  (mmm-erb-assert-non-string-syntax))
+  (mmm-erb-assert-non-string-faces))
